import { addSchema } from "@kubernetes-models/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@kubernetes-models/base";
import { register } from "@kubernetes-models/validate";
const schemaId = "gateway.networking.k8s.io.v1alpha2.ReferenceGrant";
const schema = "{\"type\":\"object\",\"properties\":{\"apiVersion\":{\"type\":\"string\",\"enum\":[\"gateway.networking.k8s.io/v1alpha2\"]},\"kind\":{\"type\":\"string\",\"enum\":[\"ReferenceGrant\"]},\"metadata\":{\"oneOf\":[{\"$ref\":\"io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#\"},{\"type\":\"null\"}]},\"spec\":{\"properties\":{\"from\":{\"items\":{\"properties\":{\"group\":{\"maxLength\":253,\"type\":\"string\",\"pattern\":\"^$|^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$\"},\"kind\":{\"maxLength\":63,\"minLength\":1,\"type\":\"string\",\"pattern\":\"^[a-zA-Z]([-a-zA-Z0-9]*[a-zA-Z0-9])?$\"},\"namespace\":{\"maxLength\":63,\"minLength\":1,\"type\":\"string\",\"pattern\":\"^[a-z0-9]([-a-z0-9]*[a-z0-9])?$\"}},\"required\":[\"group\",\"kind\",\"namespace\"],\"type\":\"object\"},\"maxItems\":16,\"minItems\":1,\"type\":\"array\"},\"to\":{\"items\":{\"properties\":{\"group\":{\"maxLength\":253,\"type\":\"string\",\"pattern\":\"^$|^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$\"},\"kind\":{\"maxLength\":63,\"minLength\":1,\"type\":\"string\",\"pattern\":\"^[a-zA-Z]([-a-zA-Z0-9]*[a-zA-Z0-9])?$\"},\"name\":{\"maxLength\":253,\"minLength\":1,\"type\":\"string\",\"nullable\":true}},\"required\":[\"group\",\"kind\"],\"type\":\"object\"},\"maxItems\":16,\"minItems\":1,\"type\":\"array\"}},\"required\":[\"from\",\"to\"],\"type\":\"object\",\"nullable\":true}},\"required\":[\"apiVersion\",\"kind\"]}";
let parsed;
/**
 * ReferenceGrant identifies kinds of resources in other namespaces that are trusted to reference the specified kinds of resources in the same namespace as the policy.
 *  Each ReferenceGrant can be used to represent a unique trust relationship. Additional Reference Grants can be used to add to the set of trusted sources of inbound references for the namespace they are defined within.
 *  A ReferenceGrant is required for all cross-namespace references in Gateway API (with the exception of cross-namespace Route-Gateway attachment, which is governed by the AllowedRoutes configuration on the Gateway, and cross-namespace Service ParentRefs on a "consumer" mesh Route, which defines routing rules applicable only to workloads in the Route namespace). ReferenceGrants allowing a reference from a Route to a Service are only applicable to BackendRefs.
 *  ReferenceGrant is a form of runtime verification allowing users to assert which cross-namespace object references are permitted. Implementations that support ReferenceGrant MUST NOT permit cross-namespace references which have no grant, and MUST respond to the removal of a grant by revoking the access that the grant allowed.
 */
export class ReferenceGrant extends Model {
    constructor(data) {
        super({
            apiVersion: ReferenceGrant.apiVersion,
            kind: ReferenceGrant.kind,
            ...data
        });
    }
}
ReferenceGrant.apiVersion = "gateway.networking.k8s.io/v1alpha2";
ReferenceGrant.kind = "ReferenceGrant";
ReferenceGrant.is = createTypeMetaGuard(ReferenceGrant);
setSchema(ReferenceGrant, schemaId, () => {
    addSchema();
    if (!parsed)
        parsed = JSON.parse(schema);
    register(schemaId, parsed);
});
